@@ -92,6 +92,9 @@ def set_dataframe_columntypes(df):
     if 'DaysSinceFirstContact' in df:
         df['DaysSinceFirstContact'] = df['DaysSinceFirstContact'].astype(
             'float16')
+    if 'DaysSincePositionStart' in df:
+        df['DaysSincePositionStart'] = df['DaysSincePositionStart'].astype(
+            'float16')
     return df
 
 
@@ -471,8 +474,10 @@ def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
 def create_new_position_flag(df,days):
     if 'DaysSincePositionStart' in df:
         logging.info('Days Since position detected, creating flag and deleting the column')
-        df[df['DaysSincePositionStart'].isna()] = 999
+        df['DaysSincePositionStart'].fillna(999)
         df['new_position'] = 0
         df.loc[df['DaysSincePositionStart']< days,'new_position'] = 1
         df.drop('DaysSincePositionStart',inplace=True)
+    else:
+        logging.info('Column not found, no changes were made.')
     return df
